/*Copyright 2009 Jose C. Bandeira R. Cardoso

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package EsforcosModelo;

/* Essa classe calcula principalmente o comprimento do arco de contato
 *do passe. Esse comprimento depende no apenas do dimetro do cilindro
 *e reduo de espessura, mas tambm do ngulo que as abas fazem com a vertical.
 *Quanto menor esse ngulo maior o arco de contato. Tambm  calculado um 
 *dimetro corrigido. Ele  o valor tal que a raiz de sua metade vezes a reduo de espessura 
 *resulta no arco de contato real.O fato da gaiola ser duo or universal  
 *levada em questo nos clculos. O arco de contato  evidentemente menor numa gaiola 
 *universal que numa duo para redues semelhantes de alma e aba.
 *
 *This class calculates mainly the lenght of the contact arc in the pass.
 *This lenght depends not only on the roll diameter and thickness reduction, but also 
 *on the angle formed by the legs with the vertical. Smaller this angle greater will be 
 *the contact arc. Is is also calculated the corrected diameter. It is a value such that
 *the square root of half of it multiplied by the thickness reduction results in the 
 *actual contact arc. The type of stand, two high or universal is taken in consideration.
 *The contact arc is of course smaller in a universal stand compared to a two high, for
 *similar reductions of web and legs. 
 *
 */
public class ModeloGeometrico {
    
    private static double larguraAba, larguraAlma, espessuraInicialAba, diametroHorizontal, diametroVertical, espessuraFinalAba, 
            espessuraInicialAlma, espessuraFinalAlma, carbono, manganes, cromo;
    private static double anguloInterno, anguloExterno, velocidade, temperatura, rotacao, tipoDeCilindro, arcoContatoAba;
    private static int metodoEsforcos;
    
    /** Creates a new instance of ModeloGeometrico */
    public ModeloGeometrico() {    
            
    }
    
    public static double getLarguraAba(){
        
        return larguraAba;
    }
    
    public static double getLarguraAlma(){
        
        return larguraAlma;
    }
    
     public static double getEspessuraInicialAba(){
        
        return espessuraInicialAba;
    }
    
     public static double getEspessuraFinalAba(){
        
        return espessuraFinalAba;
    }
     
     public static double getEspessuraInicialAlma(){
        
        return espessuraInicialAlma;
    }
    
     public static double getEspessuraFinalAlma(){
        
        return espessuraFinalAlma;
    }
     
     public static double getDiametroHorizontal(){  
        
         return diametroHorizontal;
    }  
     
     public static double getDiametroVertical(){  
        
         return diametroVertical;
    }  
     
     public static double getDiametroCorrigidoAba(){    
        
        //return arcoDeContato() / Math.sin(agarre());
         return 2 * arcoDeContatoAba() * arcoDeContatoAba() / deltaHAba();
    }
     
     public static double getAnguloInterno(){
        
        return anguloInterno;
    }
     
     public static double getAnguloExterno(){
        
        return anguloExterno;
    }
     
     public static double getCarbono(){
        
        return carbono;
    }
     
     public static double getManganes(){
        
        return manganes;
    }
     
     public static double getCromo(){
        
        return cromo;
    }
     
     public static double getVelocidade(){
        
        return velocidade;
    }
     
     public static int getMetodo(){
         
         return metodoEsforcos;
     }
     
     public static double arcoDeContatoAba(){
         
         if(diametroVertical == 0 )
             arcoDuo();
         else 
             arcoUni();
         
         return arcoContatoAba;
         
     }
     
     public static double arcoDeContatoAlma(){
         
         return Math.sqrt (diametroHorizontal / 2 * deltaHAlma());
         
     }
     
     public static void arcoDuo(){
         
         double teta = Math.acos(1 - deltaHAba() / ( diametroHorizontal / 2 * ( Math.tan(anguloInterno) + Math.tan(anguloExterno))));
         arcoContatoAba = diametroHorizontal / 2 * Math.sin(teta);
         
     }
     
     public static void arcoUni(){
         
         double teta;
         double dif = -deltaHAba();
         
         for(teta = 0; dif < 0; teta+=0.01){
         double aux1 = Math.sqrt( 1 - Math.pow(( diametroVertical / diametroHorizontal * Math.sin(teta)) , 2 ));
         dif = diametroHorizontal / 2 * ( 1 - Math.cos(teta)) * Math.tan(anguloInterno) + diametroVertical / 2 * ( 1 - aux1) - 
                 deltaHAba(); 
         }
         
         arcoContatoAba = diametroVertical / 2 * Math.sin(teta);
         System.out.println(arcoContatoAba);
     }
     
     public static double getTemperatura(){
         
         return temperatura;
     }
     
    public static double deltaHAba(){
         
         return espessuraInicialAba - espessuraFinalAba;
     } 
    
    public static double deltaHAlma(){
         
         return espessuraInicialAlma - espessuraFinalAlma;
     } 
    
    public static double somaHAba(){
         
         return espessuraInicialAba + espessuraFinalAba;
     } 
    
    public static double somaHAlma(){
         
         return espessuraInicialAlma + espessuraFinalAlma;
     } 
    
    public static double getFatorDeFormaAba(){
    
    double o2 = (1.6*coeficienteDeAtrito()*arcoDeContatoAba()-1.2*deltaHAba())/somaHAba();
    return o2;
    
    }
    
    public static double getFatorDeFormaAlma(){
    
    double o2 = (1.6*coeficienteDeAtrito()*arcoDeContatoAlma()-1.2*deltaHAlma())/somaHAlma();
    return o2;
    
    }
    
    public static double coeficienteDeAtrito(){
               
        return ( 1.05 - 0.0005 * temperatura ) * ( 1.1 - (double) tipoDeCilindro / 10 );
    
    }
    
    public static double getRotacao(){
         
         return velocidade * 60000 / ( Math.PI * diametroHorizontal );
         
     } 
    
     public static double agarreAlma(){
         
         return Math.acos( (diametroHorizontal  - (espessuraInicialAlma - espessuraFinalAlma)) / diametroHorizontal ); 
         
     } 
     
     public static double anguloNeutroAlma(){
         
         return Math.asin(0.5 * Math.sin(agarreAlma()) - ( 1 - Math.cos(agarreAlma())) / ( 2 * coeficienteDeAtrito() ));
         
     } 
     
     public void setDiametroHorizontal(double dH){
         
         diametroHorizontal =  dH;
     }
     
      public void setDiametroVertical(double dV){
         
         diametroVertical =  dV;
     }
      
       public void setLarguraAba(double lAba){
         
         larguraAba =  lAba;
     }
       
       public void setLarguraAlma(double lAlma){
         
         larguraAlma =  lAlma;
     }
       
       public void setEspessuaAlmaEnt(double entAlma){
         
         espessuraInicialAlma =  entAlma;
     }
       
       public void setEspessuaAlmaSai(double saiAlma){
         
         espessuraFinalAlma =  saiAlma;
     }
       
       public void setEspessuaAbaEnt(double entAba){
         
         espessuraInicialAba =  entAba;
     }
       
       public void setEspessuaAbaSai(double saiAba){
         
         espessuraFinalAba =  saiAba;
     }
       
       public void setAnguloInterno(double angInt){
         
         anguloInterno =  Math.PI / 180 * angInt;
     }
       
       public void setAnguloExterno(double angExt){
         
         anguloExterno =  Math.PI / 180 * angExt;
     }
       
       public void setVelocidade(double vel){
         
         velocidade =  vel;
     }
       
       public void setTemperatura(double temp){
         
         temperatura =  temp;
     }
       
       public void setTipoCilindro(int tipo){
         
         tipoDeCilindro =  tipo;
     }
       
       public void setCarbono(double C){
         
         carbono =  C;
     }
       
       public void setManganes(double Mn){
         
         manganes =  Mn;
     }
       
       public void setCromo(double Cr){
         
         cromo =  Cr;
     }
       
       public void setMetodoCalculo(int metodo){
           
         metodoEsforcos = metodo; 
         
       }
       
       
    
}